@@ -87,6 +87,21 @@ func TestDeploy(t *testing.T) {
 	testutil.CheckDeepEqual(t, "index.docker.io/library/busybox:1", dep.Spec.Template.Spec.Containers[0].Image)
 }
 
+func TestDeployLoadImages(t *testing.T) {
+	MarkIntegrationTest(t, CanRunWithoutGcp)
+
+	ns, client := SetupNamespace(t)
+
+	// first build the artifacts and output to file
+	skaffold.Build("--file-output=images.json", "--default-repo=").InDir("examples/getting-started").RunOrFail(t)
+
+	// `--default-repo=` is used to cancel the default repo that is set by default.
+	skaffold.Deploy("--build-artifacts=images.json", "--default-repo=", "--load-images=true").InDir("examples/getting-started").InNs(ns.Name).RunOrFail(t)
+
+	pod := client.GetPod("getting-started")
+	testutil.CheckContains(t, "skaffold-example", pod.Spec.Containers[0].Image)
+}
+
 func TestDeployTail(t *testing.T) {
 	MarkIntegrationTest(t, CanRunWithoutGcp)
 
