@@ -23,5 +23,5 @@ import (
 // Recommender makes recommendations based on err in the actionable error
 type Recommender interface {
 	// Makes one or more recommendations for the ErrorCode in err and updates the err with suggestions
-	Make(errCode proto.StatusCode) proto.Suggestion
+	Make(errCode proto.StatusCode) *proto.Suggestion
 }
