@@ -22,10 +22,11 @@ import (
 	"strings"
 
 	v1 "github.com/google/go-containerregistry/pkg/v1"
-	"github.com/sirupsen/logrus"
+
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 )
 
-func RetrieveConfigFile(tagged string, cfg Config) (*v1.ConfigFile, error) {
+func RetrieveConfigFile(ctx context.Context, tagged string, cfg Config) (*v1.ConfigFile, error) {
 	if strings.ToLower(tagged) == "scratch" {
 		return nil, nil
 	}
@@ -33,7 +34,7 @@ func RetrieveConfigFile(tagged string, cfg Config) (*v1.ConfigFile, error) {
 	var cf *v1.ConfigFile
 	var err error
 
-	localDocker, err := NewAPIClient(cfg)
+	localDocker, err := NewAPIClient(ctx, cfg)
 	if err == nil {
 		cf, err = localDocker.ConfigFile(context.Background(), tagged)
 	}
@@ -48,23 +49,23 @@ func RetrieveConfigFile(tagged string, cfg Config) (*v1.ConfigFile, error) {
 	return cf, err
 }
 
-func RetrieveWorkingDir(tagged string, cfg Config) (string, error) {
-	cf, err := RetrieveConfigFile(tagged, cfg)
+func RetrieveWorkingDir(ctx context.Context, tagged string, cfg Config) (string, error) {
+	cf, err := RetrieveConfigFile(ctx, tagged, cfg)
 	switch {
 	case err != nil:
 		return "", err
 	case cf == nil:
 		return "/", nil
 	case cf.Config.WorkingDir == "":
-		logrus.Debugf("Using default workdir '/' for %s", tagged)
+		log.Entry(context.TODO()).Debugf("Using default workdir '/' for %s", tagged)
 		return "/", nil
 	default:
 		return cf.Config.WorkingDir, nil
 	}
 }
 
-func RetrieveLabels(tagged string, cfg Config) (map[string]string, error) {
-	cf, err := RetrieveConfigFile(tagged, cfg)
+func RetrieveLabels(ctx context.Context, tagged string, cfg Config) (map[string]string, error) {
+	cf, err := RetrieveConfigFile(ctx, tagged, cfg)
 	switch {
 	case err != nil:
 		return nil, err
