@@ -20,6 +20,8 @@ import (
 	"sort"
 	"testing"
 
+	"google.golang.org/protobuf/testing/protocmp"
+
 	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 	"github.com/GoogleContainerTools/skaffold/proto/v1"
 	"github.com/GoogleContainerTools/skaffold/testutil"
@@ -142,7 +144,7 @@ func TestEmptyState(t *testing.T) {
 
 			// sort and compare
 			sort.Slice(builders, func(i, j int) bool { return builders[i].Type < builders[j].Type })
-			t.CheckDeepEqual(metadata, test.expected)
+			t.CheckDeepEqual(metadata, test.expected, protocmp.Transform())
 		})
 	}
 }
