@@ -67,21 +67,23 @@ func (d *ContainerManager) Start(ctx context.Context) error {
 	}
 
 	d.podWatcher.Register(d.events)
-	stopWatcher, err := d.podWatcher.Start(d.kubeContext, *d.namespaces)
+	stopWatcher, err := d.podWatcher.Start(ctx, d.kubeContext, *d.namespaces)
 	if err != nil {
 		return err
 	}
-	d.stopWatcher = stopWatcher
 
 	go func() {
 		defer stopWatcher()
-
+		l := log.Entry(ctx)
+		defer l.Tracef("containerManager: cease waiting for pod events")
+		l.Tracef("containerManager: waiting for pod events")
 		for {
 			select {
 			case <-ctx.Done():
-				return
+				l.Tracef("containerManager: context canceled, ignoring")
 			case evt, ok := <-d.events:
 				if !ok {
+					l.Tracef("containerManager: channel closed, returning")
 					return
 				}
 
@@ -98,7 +100,8 @@ func (d *ContainerManager) Stop() {
 	if d == nil {
 		return
 	}
-	d.stopWatcher()
+	d.podWatcher.Deregister(d.events)
+	close(d.events) // the receiver shouldn't really be the one to close the channel
 }
 
 func (d *ContainerManager) Name() string {
