@@ -18,6 +18,7 @@ package manifest
 
 import (
 	"fmt"
+	"regexp"
 
 	apimachinery "k8s.io/apimachinery/pkg/runtime/schema"
 
@@ -42,6 +43,20 @@ var transformableAllowlist = map[apimachinery.GroupKind]bool{
 	{Group: "argoproj.io", Kind: "Rollout"}:         true,
 }
 
+type wildcardGroupKind struct {
+	Group *regexp.Regexp
+	Kind  *regexp.Regexp
+}
+
+func (w *wildcardGroupKind) Matches(group, kind string) bool {
+	return (w.Group == nil || w.Group.Match([]byte(group))) && (w.Kind == nil || w.Kind.Match([]byte(kind)))
+}
+
+var wildcardedAllowlist = []wildcardGroupKind{
+	// add preliminary support for config connector services; group name is currently in flux
+	{Group: regexp.MustCompile(`([[:alpha:]]+\.)+cnrm\.cloud\.google\.com`), Kind: regexp.MustCompile("Service")},
+}
+
 // FieldVisitor represents the aggregation/transformation that should be performed on each traversed field.
 type FieldVisitor interface {
 	// Visit is called for each transformable key contained in the object and may apply transformations/aggregations on it.
@@ -107,7 +122,15 @@ func shouldTransformManifest(manifest map[string]interface{}) bool {
 		Kind:  gvk.Kind,
 	}
 
-	return transformableAllowlist[groupKind]
+	if result, found := transformableAllowlist[groupKind]; found {
+		return result
+	}
+	for _, w := range wildcardedAllowlist {
+		if w.Matches(gvk.Group, gvk.Kind) {
+			return true
+		}
+	}
+	return false
 }
 
 // recursiveVisitorDecorator adds recursion to a FieldVisitor.
