@@ -101,3 +101,41 @@ func TestDebugPorts(t *testing.T) {
 		Spec:       v1.PodSpec{Containers: []v1.Container{container}}}
 	testutil.CheckDeepEqual(t, []v1.ContainerPort{{Name: "dlv", ContainerPort: 56268}}, debugPorts(&pod, container))
 }
+
+func TestAddForwarder(t *testing.T) {
+	tests := []struct {
+		description        string
+		fmOptions          string
+		expectedForwarders []int
+	}{
+		{
+			description:        "nil forwarder manager",
+			fmOptions:          "",
+			expectedForwarders: []int{0, 0},
+		},
+		{
+			description:        "basic forwarder manager",
+			fmOptions:          "user",
+			expectedForwarders: []int{1, 1},
+		},
+		{
+			description:        "two options forwarder manager",
+			fmOptions:          "user,debug",
+			expectedForwarders: []int{2, 3},
+		},
+	}
+
+	for _, test := range tests {
+		testutil.Run(t, test.description, func(t *testutil.T) {
+			options := config.PortForwardOptions{}
+			options.Set(test.fmOptions)
+			fm := NewForwarderManager(&kubectl.CLI{}, &kubernetes.ImageList{}, "", "", nil, options, nil)
+
+			if fm != nil {
+				t.CheckDeepEqual(test.expectedForwarders[0], len(fm.forwarders))
+				fm.AddPodForwarder(&kubectl.CLI{}, &kubernetes.ImageList{}, "", options)
+				t.CheckDeepEqual(test.expectedForwarders[1], len(fm.forwarders))
+			}
+		})
+	}
+}
