@@ -23,9 +23,8 @@ import (
 	"io"
 	"strings"
 
-	"github.com/sirupsen/logrus"
-
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/log"
+	olog "github.com/GoogleContainerTools/skaffold/pkg/skaffold/output/log"
 )
 
 //nolint:golint
@@ -34,7 +33,7 @@ func StreamRequest(ctx context.Context, out io.Writer, formatter log.Formatter,
 	for {
 		select {
 		case <-ctx.Done():
-			logrus.Infof("%s interrupted", formatter.Name())
+			olog.Entry(ctx).Infof("%s interrupted", formatter.Name())
 			return nil
 		default:
 			// Read up to newline
