@@ -19,32 +19,32 @@ package tags
 import (
 	"testing"
 
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
 func TestSetAbsFilePaths(t *testing.T) {
 	tests := []struct {
 		description string
-		config      *latest.SkaffoldConfig
+		config      *latestV1.SkaffoldConfig
 		base        string
-		expected    *latest.SkaffoldConfig
+		expected    *latestV1.SkaffoldConfig
 	}{
 		{
 			description: "relative path",
-			config: &latest.SkaffoldConfig{
-				Pipeline: latest.Pipeline{
-					Build: latest.BuildConfig{
-						Artifacts: []*latest.Artifact{
+			config: &latestV1.SkaffoldConfig{
+				Pipeline: latestV1.Pipeline{
+					Build: latestV1.BuildConfig{
+						Artifacts: []*latestV1.Artifact{
 							{ImageName: "foo1", Workspace: "foo"},
 							{ImageName: "foo2", Workspace: `C:\a\foo`},
 						},
 					},
-					Deploy: latest.DeployConfig{
-						DeployType: latest.DeployType{
-							KptDeploy:     &latest.KptDeploy{Dir: "."},
-							KubectlDeploy: &latest.KubectlDeploy{Manifests: []string{`foo\*`, `C:\a\foo\*`}},
-							HelmDeploy: &latest.HelmDeploy{Releases: []latest.HelmRelease{
+					Deploy: latestV1.DeployConfig{
+						DeployType: latestV1.DeployType{
+							KptDeploy:     &latestV1.KptDeploy{Dir: "."},
+							KubectlDeploy: &latestV1.KubectlDeploy{Manifests: []string{`foo\*`, `C:\a\foo\*`}},
+							HelmDeploy: &latestV1.HelmDeploy{Releases: []latestV1.HelmRelease{
 								{ChartPath: `..\charts`, ValuesFiles: []string{"values1.yaml", "values2.yaml"}, SetFiles: map[string]string{"envFile": "values3.yaml", "configFile": "values4.yaml", "anotherFile": `C:\c\values5.yaml`}},
 								{RemoteChart: "foo/bar", ValuesFiles: []string{"values1.yaml", "values2.yaml"}, SetFiles: map[string]string{"envFile": "values3.yaml", "configFile": "values4.yaml", "anotherFile": `C:\c\values5.yaml`}},
 							}},
@@ -53,19 +53,19 @@ func TestSetAbsFilePaths(t *testing.T) {
 				},
 			},
 			base: `C:\a\b`,
-			expected: &latest.SkaffoldConfig{
-				Pipeline: latest.Pipeline{
-					Build: latest.BuildConfig{
-						Artifacts: []*latest.Artifact{
+			expected: &latestV1.SkaffoldConfig{
+				Pipeline: latestV1.Pipeline{
+					Build: latestV1.BuildConfig{
+						Artifacts: []*latestV1.Artifact{
 							{ImageName: "foo1", Workspace: `C:\a\b\foo`},
 							{ImageName: "foo2", Workspace: `C:\a\foo`},
 						},
 					},
-					Deploy: latest.DeployConfig{
-						DeployType: latest.DeployType{
-							KptDeploy:     &latest.KptDeploy{Dir: `C:\a\b`},
-							KubectlDeploy: &latest.KubectlDeploy{Manifests: []string{`C:\a\b\foo\*`, `C:\a\foo\*`}},
-							HelmDeploy: &latest.HelmDeploy{Releases: []latest.HelmRelease{
+					Deploy: latestV1.DeployConfig{
+						DeployType: latestV1.DeployType{
+							KptDeploy:     &latestV1.KptDeploy{Dir: `C:\a\b`},
+							KubectlDeploy: &latestV1.KubectlDeploy{Manifests: []string{`C:\a\b\foo\*`, `C:\a\foo\*`}},
+							HelmDeploy: &latestV1.HelmDeploy{Releases: []latestV1.HelmRelease{
 								{ChartPath: `C:\a\charts`, ValuesFiles: []string{`C:\a\b\values1.yaml`, `C:\a\b\values2.yaml`}, SetFiles: map[string]string{"envFile": `C:\a\b\values3.yaml`, "configFile": `C:\a\b\values4.yaml`, "anotherFile": `C:\c\values5.yaml`}},
 								{RemoteChart: "foo/bar", ValuesFiles: []string{`C:\a\b\values1.yaml`, `C:\a\b\values2.yaml`}, SetFiles: map[string]string{"envFile": `C:\a\b\values3.yaml`, "configFile": `C:\a\b\values4.yaml`, "anotherFile": `C:\c\values5.yaml`}},
 							}},
